
.. py:currentmodule:: pythreejs

FaceNormalsHelper
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: FaceNormalsHelper(object=None, size=1, color="0xffff00", linewidth=1, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.Object3D`.

    Three.js docs: https://threejs.org/docs/#api/helpers/FaceNormalsHelper


    .. py:attribute:: object

        .. sourcecode:: python

            Instance(Object3D, allow_none=True).tag(sync=True, **widget_serialization)

    .. py:attribute:: size

        .. sourcecode:: python

            CFloat(1, allow_none=False).tag(sync=True)

    .. py:attribute:: color

        .. sourcecode:: python

            Unicode("0xffff00", allow_none=False).tag(sync=True)

    .. py:attribute:: linewidth

        .. sourcecode:: python

            CFloat(1, allow_none=False).tag(sync=True)

